@@ -5,7 +5,7 @@ package Alt::Data::Frame::ButMore;
 use strict;
 use warnings;
 
-our $VERSION = '0.0044_01'; # TRIAL VERSION
+our $VERSION = '0.0050_01'; # TRIAL VERSION
 
 1;
 
@@ -21,11 +21,11 @@ Alt::Data::Frame::ButMore - Alternative implementation of Data::Frame with more
 
 =head1 VERSION
 
-version 0.0044_01
+version 0.0050_01
 
 =head1 STATUS
 
-This library is current experimental.
+This library is currently experimental.
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ As such, it supports marking missing values (C<BAD> values).
 Function signatures in docs of this library follow the
 L<Function::Parameters> conventions, for example,
 
-    function(Type1 $positional_parameter, Type2 :$named_parameter)
+    myfunc(Type1 $positional_parameter, Type2 :$named_parameter)
 
 =head1 CONSTRUCTION
 
