@@ -155,38 +155,37 @@ sub BUILD {
 }
 
 
+method _format_cell ($col, $ridx,
+                     :$na='BAD', :$isbad=$col->isbad)
+{
+    if ($isbad->at($ridx)) {
+        return $na;
+    }
+
+    if ( $col->$_DOES('PDL::DateTime') ) {
+        return $col->dt_at($ridx);
+    }
+    elsif ( $self->_is_numeric_column($col) ) {
+        if ( $col->type >= PDL::float ) {
+
+            # This is to fix some float precision problem with perl
+            # of nvsize=16, which can cause $df->string to get untidy
+            # float data to cause our test to fail.
+            return
+              sprintf( $doubleformat, $col->slice($ridx)->squeeze->string );
+        }
+    }
+    return $col->slice($ridx)->squeeze->string;
+}
+
 method _string() {
-    my $format_cell = sub {
-        my ( $col, $ridx ) = @_;
-
-        if ( $col->$_DOES('PDL::DateTime') ) {
-            return $col->dt_at($ridx);
-        }
-        elsif ( $self->_is_numeric_column($col) ) {
-            if ( $col->type >= PDL::float ) {
-
-                # This is to fix some float precision problem with perl
-                # of nvsize=16, which can cause $df->string to get untidy
-                # float data to cause our test to fail.
-                my $s = $col->slice($ridx)->squeeze->string;
-                if ( $s eq 'BAD' ) {
-                    return $s;
-                }
-                else {
-                    return sprintf( $doubleformat, $s );
-                }
-            }
-        }
-        return $col->slice($ridx)->squeeze->string;
-    };
-
     my @rows = ( [ '', @{ $self->column_names } ] );
     for my $r_idx ( 0 .. $self->number_of_rows - 1 ) {
         my $r = [
             $self->row_names->slice($r_idx)->squeeze->string,
             map {
                 my $col = $self->nth_column($_);
-                $format_cell->( $col, $r_idx );
+                $self->_format_cell( $col, $r_idx );
             } 0 .. $self->number_of_columns - 1
         ];
         push @rows, $r;
@@ -497,7 +496,7 @@ sub add_column {
 
 method copy () { 
     return ref($self)->new(
-        columns   => $self->names->map( sub { $_ => $self->at($_)->copy } ), 
+        columns   => $self->names->map( sub { $_ => $self->column($_)->copy } ),
         row_names => $self->row_names->copy
     );
 }
@@ -941,7 +940,7 @@ method _compare ($other, $mode) {
         my ( $col, $x ) = @_;
         my $a = $col->abs;
         my $b = ref($x) ? $x->abs : abs($x);
-        return ifelse( $a > $b, $a, $b ) * $TOLERANCE_REL;
+        return (ifelse( $a > $b, $a, $b ) * abs($TOLERANCE_REL));
     };
 
     state $fcompare_float = {
@@ -1051,11 +1050,11 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.0044_01
+version 0.0050_01
 
 =head1 STATUS
 
-This library is current experimental.
+This library is currently experimental.
 
 =head1 SYNOPSIS
 
@@ -1115,7 +1114,7 @@ As such, it supports marking missing values (C<BAD> values).
 Function signatures in docs of this library follow the
 L<Function::Parameters> conventions, for example,
 
-    function(Type1 $positional_parameter, Type2 :$named_parameter)
+    myfunc(Type1 $positional_parameter, Type2 :$named_parameter)
 
 =head1 CONSTRUCTION
 
