@@ -61,7 +61,7 @@ sub repeat {
         $p = $class->new( [ ( @{ $self->unpdl } ) x $n ] );
     }
     elsif ( $self->$_DOES('PDL::Factor') ) {
-        $p = $class->new( $self->levels, levels => $self->levels );
+        $p = $class->new( $self, levels => $self->levels );
         $p->{PDL} = $repeat->( $p->{PDL}, $n );
     }
     else {
@@ -153,7 +153,7 @@ Data::Frame::PDL - A mixin to add some methods to PDL
 
 =head1 VERSION
 
-version 0.0044_01
+version 0.0050_01
 
 =head1 DESCRIPTION
 
