@@ -5,7 +5,7 @@ package Data::Frame::Partial::Eval;
 use Data::Frame::Role;
 use namespace::autoclean;
 
-use Eval::Quosure 0.001;
+use Eval::Quosure 0.001001;
 use Types::Standard;
 
 use Data::Frame::Indexer qw(indexer_s);
@@ -19,7 +19,7 @@ method eval_tidy ($x) {
 
     my $expr = $is_quosure ? $x->expr : $x;
     if ( $self->exists($expr) ) {
-        return $self->at( indexer_s($expr) );
+        return $self->column($expr);
     }
 
     my $quosure = $is_quosure ? $x : Eval::Quosure->new( $expr, 1 );
@@ -34,7 +34,12 @@ method eval_tidy ($x) {
         )->flatten
     };
 
-    return $quosure->eval($column_vars);
+    try {
+        return $quosure->eval($column_vars);
+    }
+    catch {
+        die qq{Error in eval_tidy('$expr', ...) : $@ };
+    }
 }
 
 1;
@@ -51,18 +56,50 @@ Data::Frame::Partial::Eval - Partial class for data frame's eval method
 
 =head1 VERSION
 
-version 0.0044_01
+version 0.0050_01
 
 =head1 SYNOPSIS
 
+    $df->eval_tidy($x);
+
 =head1 DESCRIPTION
 
+The C<eval_tidy> method is similar to R's data frame tidy evaluation.
+
 =head1 METHODS
 
 =head2 eval_tidy
 
     eval_tidy($x)
 
+This method is similar to R's data frame tidy evaluation.
+
+Depending on C<$x>,
+
+=over 4
+
+=item * C<$x> is a reference but not an L<Eval::Quosure> object
+
+Return C<$x>.
+
+=item * C<$x> is a column name of the data frame
+
+Return the column.
+
+=item * For other C<$x>,
+
+Coerce C<$x> to an an L<Eval::Quosure> object, add columns of the data
+frame into the quosure object's captured variables, and evaluate the
+quosure object. For example, 
+
+    # $df has a column named "foo"
+    $df->eval_tidy('$foo + 1');
+
+    # above is equivalent to below
+    $df->at('foo') + 1;
+
+=back
+
 =head1 SEE ALSO
 
 L<Data::Frame>, L<Eval::Quosure>
